MethodChannelFlutterWatchConnectivity class
An implementation of FlutterWatchConnectivityPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterWatchConnectivityPlatform
- MethodChannelFlutterWatchConnectivity
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configurePages(
{required List< WatchPage> pages, required String initialPageId}) → Future<void> -
override
-
isSupported(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
Map< String, Object?> message) → Future<void> -
override
-
showPage(
String pageId) → Future< void> -
override
-
state(
) → Future< WatchConnectivityState> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited